#include "crash.h"

extern const commandtable_t
	command_pagebuf,
	command_xfs_alloc_arg,
	command_xfs_bmbt_rec,
	command_xfs_inode,
	command_xfs_log_item,
	command_xfs_mount,
	command_xfs_perag,
	command_xfs_trans,
	command_xfs_vfs,
	command_xlog,
	command_xlog_in_core,
	command_xlog_ticket;

const commandtable_t *commandtable_xfs[] = {
	&command_pagebuf,
	&command_xfs_alloc_arg,
	&command_xfs_bmbt_rec,
	&command_xfs_inode,
	&command_xfs_log_item,
	&command_xfs_mount,
	&command_xfs_perag,
	&command_xfs_trans,
	&command_xfs_vfs,
	&command_xlog,
	&command_xlog_in_core,
	&command_xlog_ticket,
};
const int ncmdtable_xfs = LENGTHOF(commandtable_xfs);
